# fontello font demo

show codes
 icon-play0xe800
 icon-pause0xe801
 icon-to-end0xe802
 icon-home0xe802
 icon-to-start0xe803
 icon-volume-down0xe804
 icon-search0xe804
 icon-volume-up0xe805
 icon-folder-open0xe805
 icon-mic-10xe806
 icon-info-circled0xe806
 icon-mic-circled0xe807
 icon-cog0xe807
 icon-cancel-circled-outline0xe808
 icon-cog-alt0xe808
 icon-cancel-circled-10xe809
 icon-trash-empty0xe80a
 icon-edit-10xe80b
 icon-pencil0xe80c
 icon-down-big0xe80c
 icon-th-list0xe80d
 icon-left-big0xe80d
 icon-th-list-outline0xe80e
 icon-right-big0xe80e
 icon-music0xe80f
 icon-list-add0xe810
 icon-up-big0xe810
 icon-trash0xe811
 icon-plus0xe812
 icon-plus-circled0xe813
 icon-left-circled0xf0a8
 icon-right-circled0xf0a9
 icon-up-circled0xf0aa
 icon-down-circled0xf0ab
 icon-list-bullet0xf0ca
 icon-list-numbered0xf0cb
 icon-sort-down0xf0dd
 icon-sort-up0xf0de
 icon-folder-open-empty0xf115